:github_url: https://github.com/bootphon/fastabx

=====================
fastabx documentation
=====================

fastabx is a Python package to perform the ABX discrimination test, and do it fast.

Navigation
==========

.. toctree::
   :titlesonly:
   :maxdepth: 1

   install
   guide
   examples/index
   api
